pub struct ImageReference { /* private fields */ }Expand description
A parsed OCI image reference with optional tag and digest.
Implementations
Sourceimpl ImageReference
impl ImageReference
Sourcepub fn parse(value: impl AsRef<str>) -> Result<ImageReference, ReferenceError>
pub fn parse(value: impl AsRef<str>) -> Result<ImageReference, ReferenceError>
Parses image reference text.
Sourcepub const fn registry(&self) -> Option<&RegistryHost>
pub const fn registry(&self) -> Option<&RegistryHost>
Returns the optional registry.
Sourcepub const fn repository(&self) -> &RepositoryName
pub const fn repository(&self) -> &RepositoryName
Returns the repository.
Examples found in repository?
examples/basic_usage.rs (line 20)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let parsed_digest: digest::OciDigest =
5 "sha256:aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".parse()?;
6 let descriptor = descriptor::OciDescriptor::new(
7 media_type::OciMediaType::image_manifest(),
8 parsed_digest,
9 descriptor::DescriptorSize::new(7023),
10 );
11 let linux_arm64 =
12 platform::OciPlatform::new(platform::OciOs::Linux, platform::OciArchitecture::Arm64);
13 let title = annotation::Annotation::title("RustUse OCI example")?;
14 let image_ref: reference::ImageReference =
15 "ghcr.io/rustuse/app:0.1.0@sha256:aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".parse()?;
16
17 assert_eq!(descriptor.size().as_u64(), 7023);
18 assert_eq!(linux_arm64.to_string(), "linux/arm64");
19 assert_eq!(title.value().as_str(), "RustUse OCI example");
20 assert_eq!(image_ref.repository().as_str(), "rustuse/app");
21 Ok(())
22}Trait Implementations
Sourceimpl Clone for ImageReference
impl Clone for ImageReference
Sourcefn clone(&self) -> ImageReference
fn clone(&self) -> ImageReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageReference
impl Debug for ImageReference
Sourceimpl Display for ImageReference
impl Display for ImageReference
Sourceimpl FromStr for ImageReference
impl FromStr for ImageReference
Sourcetype Err = ReferenceError
type Err = ReferenceError
The associated error which can be returned from parsing.
Sourcefn from_str(
value: &str,
) -> Result<ImageReference, <ImageReference as FromStr>::Err>
fn from_str( value: &str, ) -> Result<ImageReference, <ImageReference as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for ImageReference
impl Hash for ImageReference
Sourceimpl Ord for ImageReference
impl Ord for ImageReference
Sourcefn cmp(&self, other: &ImageReference) -> Ordering
fn cmp(&self, other: &ImageReference) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ImageReference
impl PartialEq for ImageReference
Sourcefn eq(&self, other: &ImageReference) -> bool
fn eq(&self, other: &ImageReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ImageReference
impl PartialOrd for ImageReference
Sourceimpl TryFrom<&str> for ImageReference
impl TryFrom<&str> for ImageReference
Sourcetype Error = ReferenceError
type Error = ReferenceError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: &str,
) -> Result<ImageReference, <ImageReference as TryFrom<&str>>::Error>
fn try_from( value: &str, ) -> Result<ImageReference, <ImageReference as TryFrom<&str>>::Error>
Performs the conversion.
impl Eq for ImageReference
impl StructuralPartialEq for ImageReference